/*$Id: //dwh/bluetooth/DWC_ble154combo/firmware/rel/1.30a-SOW05PatchV4/firmware/public_inc/hci.h#1 $*/
/**
 ********************************************************************************
 * @file    hci.h
 * @brief   This file contains all the functions prototypes for the hci.h.
 ******************************************************************************
 * @copy
 *
 *(C) COPYRIGHT 2023 SYNOPSYS, Inc. This Synopsys "product" and all associated documentation 
 *are proprietary to Synopsys, Inc. and may only be used pursuant to the terms and 
 *conditions of a written license agreement with Synopsys, Inc. All other use, 
 *reproduction, modification, or distribution of the Synopsys "product" or the associated 
 *documentation is strictly prohibited.
 *
 *
 * THE ENTIRE NOTICE ABOVE MUST BE REPRODUCED ON ALL AUTHORIZED COPIES.
 *
 * <h2><center>&copy; (C) (C) COPYRIGHT 2023 SYNOPSYS, INC.</center></h2>
 * <h2><center>&copy; 	ALL RIGHTS RESERVED</center></h2>
 *
 * \n\n<b>References</b>\n
 * -Documents folder .
 *
 * <b>Edit History For File</b>\n
 *  This section contains comments describing changes made to this file.\n
 *  Notice that changes are listed in reverse chronological order.\n
 * <table border>
 * <tr>
 * </tr>
 * </table>\n
 */

/** @defgroup  hci_intf HCI Layer
 *  @ingroup BLE_STACK_API
 *  @brief Provide APIs to interface with HCI layer, like HCI layer initialization, allocation and free of HCI buffer header, process the received HCI command packet ...etc, HCI APIS are defined in hci.h header file.
 *  @{
 */
/* Define to prevnt recursive inclusion */
#ifndef INCLUDE_HCI_H
#define INCLUDE_HCI_H

/* Includes ---------------------------------------------------------------------*/

#include <stdint.h>
#include "bsp.h"
#include "ll_intf.h"

/* Exported  Enumerations -----------------------------------------------------*/

/**
 * @brief Enumeration holding the types of the returned commands in response
 * 		  to a received HCI command.
 */
typedef enum {
	HCI_RETURN_COMMAND_TYPE_COMPLETE,
	HCI_RETURN_COMMAND_TYPE_STATUS,
} hci_return_command_type;

/* Exported  Defines -----------------------------------------------------------*/

typedef uint8_t (*hci_trnsprt_cbk)(
	ble_buff_hdr_t *ptr_evnt_hdr);

/** @ingroup  ext_hci_cmds External HCI Commands
 * @{
 */
typedef ble_stat_t (*ble_ext_custm_cb_t) (uint16_t ocf, uint8_t *pckt_p, uint8_t *evnt_pckt_p, uint8_t* params_length, hci_return_command_type* return_command_type);
/**@}
 */

/* Exported functions ---------------------------------------------------------*/

/**
 * @brief Initialize the HCI layer and Registers a callback function to the upper layer
 *
 * @param p_trnsprt_cbk : [in] callback function
 *
 * @retval always returns SUCCESS
 */
ble_stat_t ll_hci_init(
	hci_trnsprt_cbk p_trnsprt_cbk);

/**
 * @brief  get a pointer to the HCI dispatch table.
 *
 * @param  p_p_dispatch_tbl : [out] pointer to be filled by the address of the HCI dispatch table.
 */
void hci_get_dis_tbl(
	const struct hci_dispatch_tbl** p_p_dispatch_tbl);

#if !SUPPORT_HCI_EVENT_ONLY || SUPPORT_HCI_EVENT_ONLY_TESTING
#if (SUPPORT_MASTER_CONNECTION || SUPPORT_SLAVE_CONNECTION)
/**
 * @brief  Process the received ACL data packet from the host.
 *
 * @param  ptr_buff_hdr  : [in] Pointer to the HCI command packet.
 *
 * @retval ble_stat_t  : Command status to be sent to the Host.
 */
ble_stat_t hci_rcvd_acl_data_pckt_hndlr(
		ble_buff_hdr_t *ptr_buff_hdr);
#endif /* (SUPPORT_MASTER_CONNECTION || SUPPORT_SLAVE_CONNECTION) */

#if ((SUPPORT_CONNECTED_ISOCHRONOUS && (SUPPORT_MASTER_CONNECTION || SUPPORT_SLAVE_CONNECTION)) || (SUPPORT_BRD_ISOCHRONOUS))
/**
 * @brief  Process the received ISO data packet from the host.
 *
 * @param  ptr_buff_hdr  : [in] Pointer to the HCI command packet.
 *
 * @retval ble_stat_t  : Command status to be sent to the Host.
 */
ble_stat_t hci_rcvd_iso_data_pckt_hndlr(
		ble_buff_hdr_t *ptr_buff_hdr);
#endif /* ((SUPPORT_CONNECTED_ISOCHRONOUS && (SUPPORT_MASTER_CONNECTION || SUPPORT_SLAVE_CONNECTION)) || SUPPORT_BRD_ISOCHRONOUS) */
#endif /* !SUPPORT_HCI_EVENT_ONLY || SUPPORT_HCI_EVENT_ONLY_TESTING */


/**
 * @brief  Process the received HCI command packet from the host.
 *
 * @param  ptr_rcvd_pckt_strt   : [in] Pointer to the HCI command packet.
 * @param  rcvd_pckt_len   		: [in] Length of the HCI command packet.
 * @retval ble_stat_t : Command status to be sent to the Host.
 */
ble_stat_t hci_rcvd_cmd_pckt_hndlr(
	uint8_t *ptr_rcvd_pckt_strt,
	uint16_t rcvd_pckt_len);

/**
 * @brief  allocate a message structure to be sent to the HCI layer through event manager.
 *
 * @retval ble_buff_hdr_t* : pointer to the buffer header allocated.
 */
ble_buff_hdr_t* hci_alloc_msg(void);

/**
 * @brief  free an allocated message structure
 *
 * @param  ptr_hci_msg  : [in] Pointer to the message to be freed.
 */
void hci_free_msg(
		ble_buff_hdr_t *ptr_hci_msg);
/**
 * @}
 */

/** @ingroup  ext_hci_cmds External HCI Commands
 * @{
 */
/**
 * @brief Registers a custom callback function to be called when the
 * 		  hci_cstm_pckt_hndlr() cannot resolve the OCF.
 *
 * @param ext_custm_cbk :[IN] Pointer to the callback function.
 *
 * @retval False if the cbk is null, True otherwise.
 */
uint8_t hci_rgstr_ble_external_custom_cbk(ble_ext_custm_cb_t ext_custm_cbk);

/**@}
 */


#if SUPPORT_HCI_EVENT_ONLY

/**
 * @brief  Initialize event manager data/events queue call backs
 *
 * @retval ble_stat_t  None
 */
void hci_init_events_queues();
/**
 * @brief  Post data/event to appropriate queue. This function is called
 * 		   in case of sending data/events to host
 *
 * @param  ptr_evnt_hdr	data/event ble_buff_hdr to send
 *
 * @retval ble_stat_t  None
 */
uint8_t hci_queue_send_pckt(ble_buff_hdr_t *ptr_evnt_hdr);

/*
 * @brief register callback to be called sending data to host
 * @param upper_layer_cbk:  host callback
 * @retval None
 * */
void hci_rgstr_hst_cbk(hst_cbk cbk);
/*
 * @brief register callback to be called on LL queue is full
 * 		  This function should be called at initialization
 * @param cbk:  host callback
 * @retval None
 * */
void hci_rgstr_hst_cbk_ll_queue_full(hst_cbk_queue_full cbk);

/*
 * @brief sets the LE event mask in hci event only configuration
 * @param event_mask : [In] an array of 8 bytes representing new event mask
 * @retval: 		   None
 * */
void hci_ll_set_le_event_mask(uint8_t event_mask[8]);


/*
 * @brief sets the event mask in hci event only configuration
 * @param event_mask : [In] an array of 8 bytes representing new event mask
 * @retval: 		   None
 * */
void hci_ll_set_event_mask(uint8_t event_mask[8]);


/*
 * @brief sets the page 2 event mask in hci event only configuration
 * @param event_mask : [In] an array of 8 bytes representing new event mask
 * @retval: 		   None
 * */
void hci_ll_set_event_mask_page2(uint8_t event_mask[8]);

/*
 * @brief sets the custom event mask in hci event only configuration
 * @param cstm_evnt_mask : [In] custom event mask bitfield
 * @retval: 		  		None
 * */
void hci_ll_set_custom_event_mask(uint8_t cstm_evnt_mask);

#endif /* SUPPORT_HCI_EVENT_ONLY */

#endif /* INCLUDE_HCI_H */

/******************* (C) (C) COPYRIGHT 2023 SYNOPSYS, INC. *****END OF FILE****/


