/* USER CODE BEGIN Header */
/**
  ******************************************************************************
  * @file    local_debug_tables.h
  * @author  MCD Application Team
  * @brief   Real Time Debug module System and Link Layer signal
             correspondence tables
  ******************************************************************************
  * @attention
  *
  * Copyright (c) 2022 STMicroelectronics.
  * All rights reserved.
  *
  * This software is licensed under terms that can be found in the LICENSE file
  * in the root directory of this software component.
  * If no LICENSE file comes with this software, it is provided AS-IS.
  *
  ******************************************************************************
  */
/* USER CODE END Header */
#ifndef LOCAL_DEBUG_TABLES_H
#define LOCAL_DEBUG_TABLES_H

#if(RT_DEBUG_GPIO_MODULE == 1)

/*******************************/
/** System local signal table **/
/*******************************/

static const rt_debug_signal_t system_debug_table[] = {
#if (USE_RT_DEBUG_SCM_SETUP == 1)
  [SCM_SETUP] = RT_DEBUG_SCM_SETUP,
#else
  [SCM_SETUP] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_SCM_SETUP */

#if (USE_RT_DEBUG_SCM_SYSTEM_CLOCK_CONFIG == 1)
  [SCM_SYSTEM_CLOCK_CONFIG] = RT_DEBUG_SCM_SYSTEM_CLOCK_CONFIG,
#else
  [SCM_SYSTEM_CLOCK_CONFIG] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_SCM_SYSTEM_CLOCK_CONFIG */

#if (USE_RT_DEBUG_SCM_HSERDY_ISR == 1)
  [SCM_HSERDY_ISR] = RT_DEBUG_SCM_HSERDY_ISR,
#else
  [SCM_HSERDY_ISR] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_SCM_HSERDY_ISR */

#if (USE_RT_DEBUG_ADC_ACTIVATION == 1)
  [ADC_ACTIVATION] = RT_DEBUG_ADC_ACTIVATION,
#else
  [ADC_ACTIVATION] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ADC_ACTIVATION */

#if (USE_RT_DEBUG_ADC_DEACTIVATION == 1)
  [ADC_DEACTIVATION] = RT_DEBUG_ADC_DEACTIVATION,
#else
  [ADC_DEACTIVATION] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ADC_DEACTIVATION */

#if (USE_RT_DEBUG_ADC_TEMPERATURE_ACQUISITION == 1)
  [ADC_TEMPERATURE_ACQUISITION] = RT_DEBUG_ADC_TEMPERATURE_ACQUISITION,
#else
  [ADC_TEMPERATURE_ACQUISITION] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ADC_TEMPERATURE_ACQUISITION */

#if (USE_RT_DEBUG_RNG_ENABLE == 1)
  [RNG_ENABLE] = RT_DEBUG_RNG_ENABLE,
#else
  [RNG_ENABLE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RNG_ENABLE */

#if (USE_RT_DEBUG_RNG_DISABLE == 1)
  [RNG_DISABLE] = RT_DEBUG_RNG_DISABLE,
#else
  [RNG_DISABLE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RNG_DISABLE */

#if (USE_RT_DEBUG_RNG_GEN_RAND_NUM == 1)
  [RNG_GEN_RAND_NUM] = RT_DEBUG_RNG_GEN_RAND_NUM,
#else
  [RNG_GEN_RAND_NUM] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RNG_GEN_RAND_NUM */

#if (USE_RT_DEBUG_LOW_POWER_STOP_MODE_ENTER == 1)
  [LOW_POWER_STOP_MODE_ENTER] = RT_DEBUG_LOW_POWER_STOP_MODE_ENTER,
#else
  [LOW_POWER_STOP_MODE_ENTER] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LOW_POWER_STOP_MODE_ENTER */

#if (USE_RT_DEBUG_LOW_POWER_STOP_MODE_EXIT == 1)
  [LOW_POWER_STOP_MODE_EXIT] = RT_DEBUG_LOW_POWER_STOP_MODE_EXIT,
#else
  [LOW_POWER_STOP_MODE_EXIT] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LOW_POWER_STOP_MODE_EXIT */

#if (USE_RT_DEBUG_LOW_POWER_STOP_MODE_ACTIVE == 1)
  [LOW_POWER_STOP_MODE_ACTIVE] = RT_DEBUG_LOW_POWER_STOP_MODE_ACTIVE,
#else
  [LOW_POWER_STOP_MODE_ACTIVE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LOW_POWER_STOP_MODE_ACTIVE */

#if (USE_RT_DEBUG_LOW_POWER_STANDBY_MODE_ENTER == 1)
  [LOW_POWER_STANDBY_MODE_ENTER] = RT_DEBUG_LOW_POWER_STANDBY_MODE_ENTER,
#else
  [LOW_POWER_STANDBY_MODE_ENTER] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LOW_POWER_STANDBY_MODE_ENTER */

#if (USE_RT_DEBUG_LOW_POWER_STANDBY_MODE_EXIT == 1)
  [LOW_POWER_STANDBY_MODE_EXIT] = RT_DEBUG_LOW_POWER_STANDBY_MODE_EXIT,
#else
  [LOW_POWER_STANDBY_MODE_EXIT] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LOW_POWER_STANDBY_MODE_EXIT */

#if (USE_RT_DEBUG_LOW_POWER_STANDBY_MODE_ACTIVE == 1)
  [LOW_POWER_STANDBY_MODE_ACTIVE] = RT_DEBUG_LOW_POWER_STANDBY_MODE_ACTIVE,
#else
  [LOW_POWER_STANDBY_MODE_ACTIVE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LOW_POWER_STANDBY_MODE_ACTIVE */
};

/***********************************/
/** Link Layer local signal table **/
/***********************************/

static const rt_debug_signal_t linklayer_debug_table[] = {
#if (USE_RT_DEBUG_HCI_READ_DONE == 1)
  [DBG_IO_HCI_READ_DONE] = RT_DEBUG_HCI_READ_DONE,
#else
  [DBG_IO_HCI_READ_DONE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_HCI_READ_DONE */

#if (USE_RT_DEBUG_HCI_RCVD_CMD == 1)
  [DBG_IO_HCI_RCVD_CMD] = RT_DEBUG_HCI_RCVD_CMD,
#else
  [DBG_IO_HCI_RCVD_CMD] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_HCI_RCVD_CMD */

#if (USE_RT_DEBUG_HCI_WRITE_DONE == 1)
  [DBG_IO_HCI_WRITE_DONE] = RT_DEBUG_HCI_WRITE_DONE,
#else
  [DBG_IO_HCI_WRITE_DONE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_HCI_WRITE_DONE */

#if (USE_RT_DEBUG_SCHDLR_EVNT_UPDATE == 1)
  [DBG_IO_SCHDLR_EVNT_UPDATE] = RT_DEBUG_SCHDLR_EVNT_UPDATE,
#else
  [DBG_IO_SCHDLR_EVNT_UPDATE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_SCHDLR_EVNT_UPDATE */

#if (USE_RT_DEBUG_SCHDLR_TIMER_SET == 1)
  [DBG_IO_SCHDLR_TIMER_SET] = RT_DEBUG_SCHDLR_TIMER_SET,
#else
  [DBG_IO_SCHDLR_TIMER_SET] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_SCHDLR_TIMER_SET */

#if (USE_RT_DEBUG_SCHDLR_PHY_CLBR_TIMER == 1)
  [DBG_IO_SCHDLR_PHY_CLBR_TIMER] = RT_DEBUG_SCHDLR_PHY_CLBR_TIMER,
#else
  [DBG_IO_SCHDLR_PHY_CLBR_TIMER] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_SCHDLR_PHY_CLBR_TIMER */

#if (USE_RT_DEBUG_SCHDLR_EVNT_SKIPPED == 1)
  [DBG_IO_SCHDLR_EVNT_SKIPPED] = RT_DEBUG_SCHDLR_EVNT_SKIPPED,
#else
  [DBG_IO_SCHDLR_EVNT_SKIPPED] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_SCHDLR_EVNT_SKIPPED */

#if (USE_RT_DEBUG_SCHDLR_HNDL_NXT_TRACE == 1)
  [DBG_IO_SCHDLR_HNDL_NXT_TRACE] = RT_DEBUG_SCHDLR_HNDL_NXT_TRACE,
#else
  [DBG_IO_SCHDLR_HNDL_NXT_TRACE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_SCHDLR_HNDL_NXT_TRACE */

#if (USE_RT_DEBUG_ACTIVE_SCHDLR_NEAR_DETEDTED == 1)
  [DBG_IO_ACTIVE_SCHDLR_NEAR_DETEDTED] = RT_DEBUG_ACTIVE_SCHDLR_NEAR_DETEDTED,
#else
  [DBG_IO_ACTIVE_SCHDLR_NEAR_DETEDTED] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ACTIVE_SCHDLR_NEAR_DETEDTED */

#if (USE_RT_DEBUG_ACTIVE_SCHDLR_NEAR_GAP_CHECK == 1)
  [DBG_IO_ACTIVE_SCHDLR_NEAR_GAP_CHECK] = RT_DEBUG_ACTIVE_SCHDLR_NEAR_GAP_CHECK,
#else
  [DBG_IO_ACTIVE_SCHDLR_NEAR_GAP_CHECK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ACTIVE_SCHDLR_NEAR_GAP_CHECK */

#if (USE_RT_DEBUG_ACTIVE_SCHDLR_NEAR_TIME_CHECK == 1)
  [DBG_IO_ACTIVE_SCHDLR_NEAR_TIME_CHECK] = RT_DEBUG_ACTIVE_SCHDLR_NEAR_TIME_CHECK,
#else
  [DBG_IO_ACTIVE_SCHDLR_NEAR_TIME_CHECK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ACTIVE_SCHDLR_NEAR_TIME_CHECK */

#if (USE_RT_DEBUG_ACTIVE_SCHDLR_NEAR_TRACE == 1)
  [DBG_IO_ACTIVE_SCHDLR_NEAR_TRACE] = RT_DEBUG_ACTIVE_SCHDLR_NEAR_TRACE,
#else
  [DBG_IO_ACTIVE_SCHDLR_NEAR_TRACE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ACTIVE_SCHDLR_NEAR_TRACE */

#if (USE_RT_DEBUG_SCHDLR_EVNT_RGSTR == 1)
  [DBG_IO_SCHDLR_EVNT_RGSTR] = RT_DEBUG_SCHDLR_EVNT_RGSTR,
#else
  [DBG_IO_SCHDLR_EVNT_RGSTR] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_SCHDLR_EVNT_RGSTR */

#if (USE_RT_DEBUG_SCHDLR_ADD_CONFLICT_Q == 1)
  [DBG_IO_SCHDLR_ADD_CONFLICT_Q] = RT_DEBUG_SCHDLR_ADD_CONFLICT_Q,
#else
  [DBG_IO_SCHDLR_ADD_CONFLICT_Q] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_SCHDLR_ADD_CONFLICT_Q */

#if (USE_RT_DEBUG_SCHDLR_HNDL_MISSED_EVNT == 1)
  [DBG_IO_SCHDLR_HNDL_MISSED_EVNT] = RT_DEBUG_SCHDLR_HNDL_MISSED_EVNT,
#else
  [DBG_IO_SCHDLR_HNDL_MISSED_EVNT] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_SCHDLR_HNDL_MISSED_EVNT */

#if (USE_RT_DEBUG_SCHDLR_UNRGSTR_EVNT == 1)
  [DBG_IO_SCHDLR_UNRGSTR_EVNT] = RT_DEBUG_SCHDLR_UNRGSTR_EVNT,
#else
  [DBG_IO_SCHDLR_UNRGSTR_EVNT] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_SCHDLR_UNRGSTR_EVNT */

#if (USE_RT_DEBUG_SCHDLR_EXEC_EVNT_TRACE == 1)
  [DBG_IO_SCHDLR_EXEC_EVNT_TRACE] = RT_DEBUG_SCHDLR_EXEC_EVNT_TRACE,
#else
  [DBG_IO_SCHDLR_EXEC_EVNT_TRACE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_SCHDLR_EXEC_EVNT_TRACE */

#if (USE_RT_DEBUG_SCHDLR_EXEC_EVNT_ERROR == 1)
  [DBG_IO_SCHDLR_EXEC_EVNT_ERROR] = RT_DEBUG_SCHDLR_EXEC_EVNT_ERROR,
#else
  [DBG_IO_SCHDLR_EXEC_EVNT_ERROR] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_SCHDLR_EXEC_EVNT_ERROR */

#if (USE_RT_DEBUG_SCHDLR_EXEC_EVNT_WINDOW_WIDENING == 1)
  [DBG_IO_SCHDLR_EXEC_EVNT_WINDOW_WIDENING] = RT_DEBUG_SCHDLR_EXEC_EVNT_WINDOW_WIDENING,
#else
  [DBG_IO_SCHDLR_EXEC_EVNT_WINDOW_WIDENING] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_SCHDLR_EXEC_EVNT_WINDOW_WIDENING */

#if (USE_RT_DEBUG_LLHWC_CMN_CLR_ISR == 1)
  [DBG_IO_LLHWC_CMN_CLR_ISR] = RT_DEBUG_LLHWC_CMN_CLR_ISR,
#else
  [DBG_IO_LLHWC_CMN_CLR_ISR] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLHWC_CMN_CLR_ISR */

#if (USE_RT_DEBUG_LLWCC_CMN_HG_ISR == 1)
  [DBG_IO_LLWCC_CMN_HG_ISR] = RT_DEBUG_LLWCC_CMN_HG_ISR,
#else
  [DBG_IO_LLWCC_CMN_HG_ISR] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLWCC_CMN_HG_ISR */

#if (USE_RT_DEBUG_LLHWC_CMN_LW_ISR == 1)
  [DBG_IO_LLHWC_CMN_LW_ISR] = RT_DEBUG_LLHWC_CMN_LW_ISR,
#else
  [DBG_IO_LLHWC_CMN_LW_ISR] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLHWC_CMN_LW_ISR */

#if (USE_RT_DEBUG_LLHWC_CMN_CLR_TIMER_ERROR == 1)
  [DBG_IO_LLHWC_CMN_CLR_TIMER_ERROR] = RT_DEBUG_LLHWC_CMN_CLR_TIMER_ERROR,
#else
  [DBG_IO_LLHWC_CMN_CLR_TIMER_ERROR] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLHWC_CMN_CLR_TIMER_ERROR */

#if (USE_RT_DEBUG_LLHWC_LL_ISR == 1)
  [DBG_IO_LLHWC_LL_ISR] = RT_DEBUG_LLHWC_LL_ISR,
#else
  [DBG_IO_LLHWC_LL_ISR] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLHWC_LL_ISR */

#if (USE_RT_DEBUG_LLHWC_SPLTMR_SET == 1)
  [DBG_IO_LLHWC_SPLTMR_SET] = RT_DEBUG_LLHWC_SPLTMR_SET,
#else
  [DBG_IO_LLHWC_SPLTMR_SET] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLHWC_SPLTMR_SET */

#if (USE_RT_DEBUG_LLHWC_SPLTMR_GET == 1)
  [DBG_IO_LLHWC_SPLTMR_GET] = RT_DEBUG_LLHWC_SPLTMR_GET,
#else
  [DBG_IO_LLHWC_SPLTMR_GET] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLHWC_SPLTMR_GET */

#if (USE_RT_DEBUG_LLHWC_LOW_ISR == 1)
  [DBG_IO_LLHWC_LOW_ISR] = RT_DEBUG_LLHWC_LOW_ISR,
#else
  [DBG_IO_LLHWC_LOW_ISR] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLHWC_LOW_ISR */

#if (USE_RT_DEBUG_LLHWC_STOP_SCN == 1)
  [DBG_IO_LLHWC_STOP_SCN] = RT_DEBUG_LLHWC_STOP_SCN,
#else
  [DBG_IO_LLHWC_STOP_SCN] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLHWC_STOP_SCN */

#if (USE_RT_DEBUG_LLHWC_WAIT_ENVT_ON_AIR == 1)
  [DBG_IO_LLHWC_WAIT_ENVT_ON_AIR] = RT_DEBUG_LLHWC_WAIT_ENVT_ON_AIR,
#else
  [DBG_IO_LLHWC_WAIT_ENVT_ON_AIR] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLHWC_WAIT_ENVT_ON_AIR */

#if (USE_RT_DEBUG_LLHWC_SET_CONN_EVNT_PARAM == 1)
  [DBG_IO_LLHWC_SET_CONN_EVNT_PARAM] = RT_DEBUG_LLHWC_SET_CONN_EVNT_PARAM,
#else
  [DBG_IO_LLHWC_SET_CONN_EVNT_PARAM] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLHWC_SET_CONN_EVNT_PARAM */

#if (USE_RT_DEBUG_POST_EVNT == 1)
  [DBG_IO_POST_EVNT] = RT_DEBUG_POST_EVNT,
#else
  [DBG_IO_POST_EVNT] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_POST_EVNT */

#if (USE_RT_DEBUG_HNDL_ALL_EVNTS == 1)
  [DBG_IO_HNDL_ALL_EVNTS] = RT_DEBUG_HNDL_ALL_EVNTS,
#else
  [DBG_IO_HNDL_ALL_EVNTS] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_HNDL_ALL_EVNTS */

#if (USE_RT_DEBUG_PROCESS_EVNT == 1)
  [DBG_IO_PROCESS_EVNT] = RT_DEBUG_PROCESS_EVNT,
#else
  [DBG_IO_PROCESS_EVNT] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_PROCESS_EVNT */

#if (USE_RT_DEBUG_PROCESS_ISO_DATA == 1)
  [DBG_IO_PROCESS_ISO_DATA] = RT_DEBUG_PROCESS_ISO_DATA,
#else
  [DBG_IO_PROCESS_ISO_DATA] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_PROCESS_ISO_DATA */

#if (USE_RT_DEBUG_ALLOC_TX_ISO_EMPTY_PKT == 1)
  [DBG_IO_ALLOC_TX_ISO_EMPTY_PKT] = RT_DEBUG_ALLOC_TX_ISO_EMPTY_PKT,
#else
  [DBG_IO_ALLOC_TX_ISO_EMPTY_PKT] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ALLOC_TX_ISO_EMPTY_PKT */

#if (USE_RT_DEBUG_BIG_FREE_EMPTY_PKTS == 1)
  [DBG_IO_BIG_FREE_EMPTY_PKTS] = RT_DEBUG_BIG_FREE_EMPTY_PKTS,
#else
  [DBG_IO_BIG_FREE_EMPTY_PKTS] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_BIG_FREE_EMPTY_PKTS */

#if (USE_RT_DEBUG_RECOMBINE_UNFRMD_DATA_OK == 1)
  [DBG_IO_RECOMBINE_UNFRMD_DATA_OK] = RT_DEBUG_RECOMBINE_UNFRMD_DATA_OK,
#else
  [DBG_IO_RECOMBINE_UNFRMD_DATA_OK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RECOMBINE_UNFRMD_DATA_OK */

#if (USE_RT_DEBUG_RECOMBINE_UNFRMD_DATA_CRC == 1)
  [DBG_IO_RECOMBINE_UNFRMD_DATA_CRC] = RT_DEBUG_RECOMBINE_UNFRMD_DATA_CRC,
#else
  [DBG_IO_RECOMBINE_UNFRMD_DATA_CRC] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RECOMBINE_UNFRMD_DATA_CRC */

#if (USE_RT_DEBUG_RECOMBINE_UNFRMD_DATA_NoRX == 1)
  [DBG_IO_RECOMBINE_UNFRMD_DATA_NoRX] = RT_DEBUG_RECOMBINE_UNFRMD_DATA_NoRX,
#else
  [DBG_IO_RECOMBINE_UNFRMD_DATA_NoRX] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RECOMBINE_UNFRMD_DATA_NoRX */

#if (USE_RT_DEBUG_RECOMBINE_UNFRMD_DATA_TRACE == 1)
  [DBG_IO_RECOMBINE_UNFRMD_DATA_TRACE] = RT_DEBUG_RECOMBINE_UNFRMD_DATA_TRACE,
#else
  [DBG_IO_RECOMBINE_UNFRMD_DATA_TRACE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RECOMBINE_UNFRMD_DATA_TRACE */

#if (USE_RT_DEBUG_ISO_HNDL_SDU == 1)
  [DBG_IO_ISO_HNDL_SDU] = RT_DEBUG_ISO_HNDL_SDU,
#else
  [DBG_IO_ISO_HNDL_SDU] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ISO_HNDL_SDU */

#if (USE_RT_DEBUG_LL_INTF_INIT == 1)
  [DBG_IO_LL_INTF_INIT] = RT_DEBUG_LL_INTF_INIT,
#else
  [DBG_IO_LL_INTF_INIT] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LL_INTF_INIT */

#if (USE_RT_DEBUG_DATA_TO_CNTRLR == 1)
  [DBG_IO_DATA_TO_CNTRLR] = RT_DEBUG_DATA_TO_CNTRLR,
#else
  [DBG_IO_DATA_TO_CNTRLR] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_DATA_TO_CNTRLR */

#if (USE_RT_DEBUG_FREE_LL_PKT_HNDLR == 1)
  [DBG_IO_FREE_LL_PKT_HNDLR] = RT_DEBUG_FREE_LL_PKT_HNDLR,
#else
  [DBG_IO_FREE_LL_PKT_HNDLR] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_FREE_LL_PKT_HNDLR */

#if (USE_RT_DEBUG_PHY_INIT_CLBR_TRACE == 1)
  [DBG_IO_PHY_INIT_CLBR_TRACE] = RT_DEBUG_PHY_INIT_CLBR_TRACE,
#else
  [DBG_IO_PHY_INIT_CLBR_TRACE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_PHY_INIT_CLBR_TRACE */

#if (USE_RT_DEBUG_PHY_INIT_CLBR_SINGLE_CH == 1)
  [DBG_IO_PHY_INIT_CLBR_SINGLE_CH] = RT_DEBUG_PHY_INIT_CLBR_SINGLE_CH,
#else
  [DBG_IO_PHY_INIT_CLBR_SINGLE_CH] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_PHY_INIT_CLBR_SINGLE_CH */

#if (USE_RT_DEBUG_PHY_CLBR_STRTD == 1)
  [DBG_IO_PHY_CLBR_STRTD] = RT_DEBUG_PHY_CLBR_STRTD,
#else
  [DBG_IO_PHY_CLBR_STRTD] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_PHY_CLBR_STRTD */

#if (USE_RT_DEBUG_PHY_CLBR_EXEC == 1)
  [DBG_IO_PHY_CLBR_EXEC] = RT_DEBUG_PHY_CLBR_EXEC,
#else
  [DBG_IO_PHY_CLBR_EXEC] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_PHY_CLBR_EXEC */

#if (USE_RT_DEBUG_RCO_STRT_STOP_RUNTIME_CLBR_ACTV == 1)
  [DBG_IO_RCO_STRT_STOP_RUNTIME_CLBR_ACTV] = RT_DEBUG_RCO_STRT_STOP_RUNTIME_CLBR_ACTV,
#else
  [DBG_IO_RCO_STRT_STOP_RUNTIME_CLBR_ACTV] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RCO_STRT_STOP_RUNTIME_CLBR_ACTV */

#if (USE_RT_DEBUG_RCO_STRT_STOP_RUNTIME_RCO_CLBR == 1)
  [DBG_IO_RCO_STRT_STOP_RUNTIME_RCO_CLBR] = RT_DEBUG_RCO_STRT_STOP_RUNTIME_RCO_CLBR,
#else
  [DBG_IO_RCO_STRT_STOP_RUNTIME_RCO_CLBR] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RCO_STRT_STOP_RUNTIME_RCO_CLBR */

#if (USE_RT_DEBUG_STRT_STOP_RUNTIME_RCO_CLBR_SWT == 1)
  [DBG_IO_STRT_STOP_RUNTIME_RCO_CLBR_SWT] = RT_DEBUG_STRT_STOP_RUNTIME_RCO_CLBR_SWT,
#else
  [DBG_IO_STRT_STOP_RUNTIME_RCO_CLBR_SWT] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_STRT_STOP_RUNTIME_RCO_CLBR_SWT */

#if (USE_RT_DEBUG_STRT_STOP_RUNTIME_RCO_CLBR_TRACE == 1)
  [DBG_IO_STRT_STOP_RUNTIME_RCO_CLBR_TRACE] = RT_DEBUG_STRT_STOP_RUNTIME_RCO_CLBR_TRACE,
#else
  [DBG_IO_STRT_STOP_RUNTIME_RCO_CLBR_TRACE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_STRT_STOP_RUNTIME_RCO_CLBR_TRACE */

#if (USE_RT_DEBUG_RCO_ISR_TRACE == 1)
  [DBG_IO_RCO_ISR_TRACE] = RT_DEBUG_RCO_ISR_TRACE,
#else
  [DBG_IO_RCO_ISR_TRACE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RCO_ISR_TRACE */

#if (USE_RT_DEBUG_RCO_ISR_COMPENDATE == 1)
  [DBG_IO_RCO_ISR_COMPENDATE] = RT_DEBUG_RCO_ISR_COMPENDATE,
#else
  [DBG_IO_RCO_ISR_COMPENDATE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RCO_ISR_COMPENDATE */

#if (USE_RT_DEBUG_RAL_STRT_TX == 1)
  [DBG_IO_RAL_STRT_TX] = RT_DEBUG_RAL_STRT_TX,
#else
  [DBG_IO_RAL_STRT_TX] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RAL_STRT_TX */

#if (USE_RT_DEBUG_RAL_ISR_TIMER_ERROR == 1)
  [DBG_IO_RAL_ISR_TIMER_ERROR] = RT_DEBUG_RAL_ISR_TIMER_ERROR,
#else
  [DBG_IO_RAL_ISR_TIMER_ERROR] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RAL_ISR_TIMER_ERROR */

#if (USE_RT_DEBUG_RAL_ISR_TRACE == 1)
  [DBG_IO_RAL_ISR_TRACE] = RT_DEBUG_RAL_ISR_TRACE,
#else
  [DBG_IO_RAL_ISR_TRACE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RAL_ISR_TRACE */

#if (USE_RT_DEBUG_RAL_STOP_OPRTN == 1)
  [DBG_IO_RAL_STOP_OPRTN] = RT_DEBUG_RAL_STOP_OPRTN,
#else
  [DBG_IO_RAL_STOP_OPRTN] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RAL_STOP_OPRTN */

#if (USE_RT_DEBUG_RAL_STRT_RX == 1)
  [DBG_IO_RAL_STRT_RX] = RT_DEBUG_RAL_STRT_RX,
#else
  [DBG_IO_RAL_STRT_RX] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RAL_STRT_RX */

#if (USE_RT_DEBUG_RAL_DONE_CLBK_TX == 1)
  [DBG_IO_RAL_DONE_CLBK_TX] = RT_DEBUG_RAL_DONE_CLBK_TX,
#else
  [DBG_IO_RAL_DONE_CLBK_TX] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RAL_DONE_CLBK_TX */

#if (USE_RT_DEBUG_RAL_DONE_CLBK_RX == 1)
  [DBG_IO_RAL_DONE_CLBK_RX] = RT_DEBUG_RAL_DONE_CLBK_RX,
#else
  [DBG_IO_RAL_DONE_CLBK_RX] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RAL_DONE_CLBK_RX */

#if (USE_RT_DEBUG_RAL_DONE_CLBK_ED == 1)
  [DBG_IO_RAL_DONE_CLBK_ED] = RT_DEBUG_RAL_DONE_CLBK_ED,
#else
  [DBG_IO_RAL_DONE_CLBK_ED] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RAL_DONE_CLBK_ED */

#if (USE_RT_DEBUG_RAL_ED_SCAN == 1)
  [DBG_IO_RAL_ED_SCAN] = RT_DEBUG_RAL_ED_SCAN,
#else
  [DBG_IO_RAL_ED_SCAN] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RAL_ED_SCAN */

#if (USE_RT_DEBUG_ERROR_MEM_CAP_EXCED == 1)
  [DBG_IO_ERROR_MEM_CAP_EXCED] = RT_DEBUG_ERROR_MEM_CAP_EXCED,
#else
  [DBG_IO_ERROR_MEM_CAP_EXCED] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ERROR_MEM_CAP_EXCED */

#if (USE_RT_DEBUG_ERROR_COMMAND_DISALLOWED == 1)
  [DBG_IO_ERROR_COMMAND_DISALLOWED] = RT_DEBUG_ERROR_COMMAND_DISALLOWED,
#else
  [DBG_IO_ERROR_COMMAND_DISALLOWED] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ERROR_COMMAND_DISALLOWED */

#if (USE_RT_DEBUG_PTA_INIT == 1)
  [DBG_IO_PTA_INIT] = RT_DEBUG_PTA_INIT,
#else
  [DBG_IO_PTA_INIT] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_PTA_INIT */

#if (USE_RT_DEBUG_PTA_EN == 1)
  [DBG_IO_PTA_EN] = RT_DEBUG_PTA_EN,
#else
  [DBG_IO_PTA_EN] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_PTA_EN */

#if (USE_RT_DEBUG_LLHWC_PTA_SET_EN == 1)
  [DBG_IO_LLHWC_PTA_SET_EN] = RT_DEBUG_LLHWC_PTA_SET_EN,
#else
  [DBG_IO_LLHWC_PTA_SET_EN] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLHWC_PTA_SET_EN */

#if (USE_RT_DEBUG_LLHWC_PTA_SET_PARAMS == 1)
  [DBG_IO_LLHWC_PTA_SET_PARAMS] = RT_DEBUG_LLHWC_PTA_SET_PARAMS,
#else
  [DBG_IO_LLHWC_PTA_SET_PARAMS] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLHWC_PTA_SET_PARAMS */

#if (USE_RT_DEBUG_COEX_STRT_ON_IDLE == 1)
  [DBG_IO_COEX_STRT_ON_IDLE] = RT_DEBUG_COEX_STRT_ON_IDLE,
#else
  [DBG_IO_COEX_STRT_ON_IDLE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_COEX_STRT_ON_IDLE */

#if (USE_RT_DEBUG_COEX_ASK_FOR_AIR == 1)
  [DBG_IO_COEX_ASK_FOR_AIR] = RT_DEBUG_COEX_ASK_FOR_AIR,
#else
  [DBG_IO_COEX_ASK_FOR_AIR] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_COEX_ASK_FOR_AIR */

#if (USE_RT_DEBUG_COEX_TIMER_EVNT_CLBK == 1)
  [DBG_IO_COEX_TIMER_EVNT_CLBK] = RT_DEBUG_COEX_TIMER_EVNT_CLBK,
#else
  [DBG_IO_COEX_TIMER_EVNT_CLBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_COEX_TIMER_EVNT_CLBK */

#if (USE_RT_DEBUG_COEX_STRT_ONE_SHOT == 1)
  [DBG_IO_COEX_STRT_ONE_SHOT] = RT_DEBUG_COEX_STRT_ONE_SHOT,
#else
  [DBG_IO_COEX_STRT_ONE_SHOT] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_COEX_STRT_ONE_SHOT */

#if (USE_RT_DEBUG_COEX_FORCE_STOP_RX == 1)
  [DBG_IO_COEX_FORCE_STOP_RX] = RT_DEBUG_COEX_FORCE_STOP_RX,
#else
  [DBG_IO_COEX_FORCE_STOP_RX] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_COEX_FORCE_STOP_RX */

#if (USE_RT_DEBUG_LLHWC_ADV_DONE == 1)
  [DBG_IO_LLHWC_ADV_DONE] = RT_DEBUG_LLHWC_ADV_DONE,
#else
  [DBG_IO_LLHWC_ADV_DONE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLHWC_ADV_DONE */

#if (USE_RT_DEBUG_LLHWC_SCN_DONE == 1)
  [DBG_IO_LLHWC_SCN_DONE] = RT_DEBUG_LLHWC_SCN_DONE,
#else
  [DBG_IO_LLHWC_SCN_DONE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLHWC_SCN_DONE */

#if (USE_RT_DEBUG_LLHWC_INIT_DONE == 1)
  [DBG_IO_LLHWC_INIT_DONE] = RT_DEBUG_LLHWC_INIT_DONE,
#else
  [DBG_IO_LLHWC_INIT_DONE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLHWC_INIT_DONE */

#if (USE_RT_DEBUG_LLHWC_CONN_DONE == 1)
  [DBG_IO_LLHWC_CONN_DONE] = RT_DEBUG_LLHWC_CONN_DONE,
#else
  [DBG_IO_LLHWC_CONN_DONE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLHWC_CONN_DONE */

#if (USE_RT_DEBUG_LLHWC_CIG_DONE == 1)
  [DBG_IO_LLHWC_CIG_DONE] = RT_DEBUG_LLHWC_CIG_DONE,
#else
  [DBG_IO_LLHWC_CIG_DONE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLHWC_CIG_DONE */

#if (USE_RT_DEBUG_LLHWC_BIG_DONE == 1)
  [DBG_IO_LLHWC_BIG_DONE] = RT_DEBUG_LLHWC_BIG_DONE,
#else
  [DBG_IO_LLHWC_BIG_DONE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLHWC_BIG_DONE */

#if (USE_RT_DEBUG_OS_TMR_CREATE == 1)
  [DBG_IO_OS_TMR_CREATE] = RT_DEBUG_OS_TMR_CREATE,
#else
  [DBG_IO_OS_TMR_CREATE] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_OS_TMR_CREATE */

#if (USE_RT_DEBUG_ADV_EXT_TIMEOUT_CBK == 1)
  [DBG_IO_ADV_EXT_TIMEOUT_CBK] = RT_DEBUG_ADV_EXT_TIMEOUT_CBK,
#else
  [DBG_IO_ADV_EXT_TIMEOUT_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ADV_EXT_TIMEOUT_CBK */

#if (USE_RT_DEBUG_ADV_EXT_SCN_DUR_CBK == 1)
  [DBG_IO_ADV_EXT_SCN_DUR_CBK] = RT_DEBUG_ADV_EXT_SCN_DUR_CBK,
#else
  [DBG_IO_ADV_EXT_SCN_DUR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ADV_EXT_SCN_DUR_CBK */

#if (USE_RT_DEBUG_ADV_EXT_SCN_PERIOD_CBK == 1)
  [DBG_IO_ADV_EXT_SCN_PERIOD_CBK] = RT_DEBUG_ADV_EXT_SCN_PERIOD_CBK,
#else
  [DBG_IO_ADV_EXT_SCN_PERIOD_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ADV_EXT_SCN_PERIOD_CBK */

#if (USE_RT_DEBUG_ADV_EXT_PRDC_SCN_TIMEOUT_CBK == 1)
  [DBG_IO_ADV_EXT_PRDC_SCN_TIMEOUT_CBK] = RT_DEBUG_ADV_EXT_PRDC_SCN_TIMEOUT_CBK,
#else
  [DBG_IO_ADV_EXT_PRDC_SCN_TIMEOUT_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ADV_EXT_PRDC_SCN_TIMEOUT_CBK */

#if (USE_RT_DEBUG_BIS_SYNC_TIMEOUT_TMR_CBK == 1)
  [DBG_IO_BIS_SYNC_TIMEOUT_TMR_CBK] = RT_DEBUG_BIS_SYNC_TIMEOUT_TMR_CBK,
#else
  [DBG_IO_BIS_SYNC_TIMEOUT_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_BIS_SYNC_TIMEOUT_TMR_CBK */

#if (USE_RT_DEBUG_BIS_TERM_TMR_CBK == 1)
  [DBG_IO_BIS_TERM_TMR_CBK] = RT_DEBUG_BIS_TERM_TMR_CBK,
#else
  [DBG_IO_BIS_TERM_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_BIS_TERM_TMR_CBK */

#if (USE_RT_DEBUG_BIS_TST_MODE_CBK == 1)
  [DBG_IO_BIS_TST_MODE_CBK] = RT_DEBUG_BIS_TST_MODE_CBK,
#else
  [DBG_IO_BIS_TST_MODE_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_BIS_TST_MODE_CBK */

#if (USE_RT_DEBUG_BIS_TST_MODE_TMR_CBK == 1)
  [DBG_IO_BIS_TST_MODE_TMR_CBK] = RT_DEBUG_BIS_TST_MODE_TMR_CBK,
#else
  [DBG_IO_BIS_TST_MODE_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_BIS_TST_MODE_TMR_CBK */

#if (USE_RT_DEBUG_ISO_POST_TMR_CBK == 1)
  [DBG_IO_ISO_POST_TMR_CBK] = RT_DEBUG_ISO_POST_TMR_CBK,
#else
  [DBG_IO_ISO_POST_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ISO_POST_TMR_CBK */

#if (USE_RT_DEBUG_ISO_TST_MODE_TMR_CBK == 1)
  [DBG_IO_ISO_TST_MODE_TMR_CBK] = RT_DEBUG_ISO_TST_MODE_TMR_CBK,
#else
  [DBG_IO_ISO_TST_MODE_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ISO_TST_MODE_TMR_CBK */

#if (USE_RT_DEBUG_CONN_POST_TMR_CBK == 1)
  [DBG_IO_CONN_POST_TMR_CBK] = RT_DEBUG_CONN_POST_TMR_CBK,
#else
  [DBG_IO_CONN_POST_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_CONN_POST_TMR_CBK */

#if (USE_RT_DEBUG_EVNT_SCHDLR_TMR_CBK == 1)
  [DBG_IO_EVNT_SCHDLR_TMR_CBK] = RT_DEBUG_EVNT_SCHDLR_TMR_CBK,
#else
  [DBG_IO_EVNT_SCHDLR_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_EVNT_SCHDLR_TMR_CBK */

#if (USE_RT_DEBUG_HCI_POST_TMR_CBK == 1)
  [DBG_IO_HCI_POST_TMR_CBK] = RT_DEBUG_HCI_POST_TMR_CBK,
#else
  [DBG_IO_HCI_POST_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_HCI_POST_TMR_CBK */

#if (USE_RT_DEBUG_LLCP_POST_TMR_CBK == 1)
  [DBG_IO_LLCP_POST_TMR_CBK] = RT_DEBUG_LLCP_POST_TMR_CBK,
#else
  [DBG_IO_LLCP_POST_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLCP_POST_TMR_CBK */

#if (USE_RT_DEBUG_LLHWC_ENRGY_DETECT_CBK == 1)
  [DBG_IO_LLHWC_ENRGY_DETECT_CBK] = RT_DEBUG_LLHWC_ENRGY_DETECT_CBK,
#else
  [DBG_IO_LLHWC_ENRGY_DETECT_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_LLHWC_ENRGY_DETECT_CBK */

#if (USE_RT_DEBUG_PRVCY_POST_TMR_CBK == 1)
  [DBG_IO_PRVCY_POST_TMR_CBK] = RT_DEBUG_PRVCY_POST_TMR_CBK,
#else
  [DBG_IO_PRVCY_POST_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_PRVCY_POST_TMR_CBK */

#if (USE_RT_DEBUG_ANT_PRPR_TMR_CBK == 1)
  [DBG_IO_ANT_PRPR_TMR_CBK] = RT_DEBUG_ANT_PRPR_TMR_CBK,
#else
  [DBG_IO_ANT_PRPR_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ANT_PRPR_TMR_CBK */

#if (USE_RT_DEBUG_COEX_TMR_FRC_STOP_AIR_GRANT_CBK == 1)
  [DBG_IO_COEX_TMR_FRC_STOP_AIR_GRANT_CBK] = RT_DEBUG_COEX_TMR_FRC_STOP_AIR_GRANT_CBK,
#else
  [DBG_IO_COEX_TMR_FRC_STOP_AIR_GRANT_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_COEX_TMR_FRC_STOP_AIR_GRANT_CBK */

#if (USE_RT_DEBUG_MLME_RX_EN_TMR_CBK == 1)
  [DBG_IO_MLME_RX_EN_TMR_CBK] = RT_DEBUG_MLME_RX_EN_TMR_CBK,
#else
  [DBG_IO_MLME_RX_EN_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_MLME_RX_EN_TMR_CBK */

#if (USE_RT_DEBUG_MLME_GNRC_TMR_CBK == 1)
  [DBG_IO_MLME_GNRC_TMR_CBK] = RT_DEBUG_MLME_GNRC_TMR_CBK,
#else
  [DBG_IO_MLME_GNRC_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_MLME_GNRC_TMR_CBK */

#if (USE_RT_DEBUG_MIB_JOIN_LST_TMR_CBK == 1)
  [DBG_IO_MIB_JOIN_LST_TMR_CBK] = RT_DEBUG_MIB_JOIN_LST_TMR_CBK,
#else
  [DBG_IO_MIB_JOIN_LST_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_MIB_JOIN_LST_TMR_CBK */

#if (USE_RT_DEBUG_MLME_PWR_PRES_TMR_CBK == 1)
  [DBG_IO_MLME_PWR_PRES_TMR_CBK] = RT_DEBUG_MLME_PWR_PRES_TMR_CBK,
#else
  [DBG_IO_MLME_PWR_PRES_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_MLME_PWR_PRES_TMR_CBK */

#if (USE_RT_DEBUG_PRESISTENCE_TMR_CBK == 1)
  [DBG_IO_PRESISTENCE_TMR_CBK] = RT_DEBUG_PRESISTENCE_TMR_CBK,
#else
  [DBG_IO_PRESISTENCE_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_PRESISTENCE_TMR_CBK */

#if (USE_RT_DEBUG_RADIO_PHY_PRDC_CLBK_TMR_CBK == 1)
  [DBG_IO_RADIO_PHY_PRDC_CLBK_TMR_CBK] = RT_DEBUG_RADIO_PHY_PRDC_CLBK_TMR_CBK,
#else
  [DBG_IO_RADIO_PHY_PRDC_CLBK_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RADIO_PHY_PRDC_CLBK_TMR_CBK */

#if (USE_RT_DEBUG_RADIO_CSMA_TMR_CBK == 1)
  [DBG_IO_RADIO_CSMA_TMR_CBK] = RT_DEBUG_RADIO_CSMA_TMR_CBK,
#else
  [DBG_IO_RADIO_CSMA_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RADIO_CSMA_TMR_CBK */

#if (USE_RT_DEBUG_RADIO_CSL_RCV_TMR_CBK == 1)
  [DBG_IO_RADIO_CSL_RCV_TMR_CBK] = RT_DEBUG_RADIO_CSL_RCV_TMR_CBK,
#else
  [DBG_IO_RADIO_CSL_RCV_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RADIO_CSL_RCV_TMR_CBK */

#if (USE_RT_DEBUG_ED_TMR_CBK == 1)
  [DBG_IO_ED_TMR_CBK] = RT_DEBUG_ED_TMR_CBK,
#else
  [DBG_IO_ED_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ED_TMR_CBK */

#if (USE_RT_DEBUG_DIO_EXT_TMR_CBK == 1)
  [DBG_IO_DIO_EXT_TMR_CBK] = RT_DEBUG_DIO_EXT_TMR_CBK,
#else
  [DBG_IO_DIO_EXT_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_DIO_EXT_TMR_CBK */

#if (USE_RT_DEBUG_RCO_CLBR_TMR_CBK == 1)
  [DBG_IO_RCO_CLBR_TMR_CBK] = RT_DEBUG_RCO_CLBR_TMR_CBK,
#else
  [DBG_IO_RCO_CLBR_TMR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RCO_CLBR_TMR_CBK */

#if (USE_RT_DEBUG_ADV_EXT_MNGR_ADV_CBK == 1)
  [DBG_IO_ADV_EXT_MNGR_ADV_CBK] = RT_DEBUG_ADV_EXT_MNGR_ADV_CBK,
#else
  [DBG_IO_ADV_EXT_MNGR_ADV_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ADV_EXT_MNGR_ADV_CBK */

#if (USE_RT_DEBUG_ADV_EXT_MNGR_SCN_CBK == 1)
  [DBG_IO_ADV_EXT_MNGR_SCN_CBK] = RT_DEBUG_ADV_EXT_MNGR_SCN_CBK,
#else
  [DBG_IO_ADV_EXT_MNGR_SCN_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ADV_EXT_MNGR_SCN_CBK */

#if (USE_RT_DEBUG_ADV_EXT_MNGR_SCN_ERR_CBK == 1)
  [DBG_IO_ADV_EXT_MNGR_SCN_ERR_CBK] = RT_DEBUG_ADV_EXT_MNGR_SCN_ERR_CBK,
#else
  [DBG_IO_ADV_EXT_MNGR_SCN_ERR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ADV_EXT_MNGR_SCN_ERR_CBK */

#if (USE_RT_DEBUG_ADV_EXT_MNGR_PRDC_SCN_CBK == 1)
  [DBG_IO_ADV_EXT_MNGR_PRDC_SCN_CBK] = RT_DEBUG_ADV_EXT_MNGR_PRDC_SCN_CBK,
#else
  [DBG_IO_ADV_EXT_MNGR_PRDC_SCN_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ADV_EXT_MNGR_PRDC_SCN_CBK */

#if (USE_RT_DEBUG_ADV_EXT_MNGR_PRDC_SCN_ERR_CBK == 1)
  [DBG_IO_ADV_EXT_MNGR_PRDC_SCN_ERR_CBK] = RT_DEBUG_ADV_EXT_MNGR_PRDC_SCN_ERR_CBK,
#else
  [DBG_IO_ADV_EXT_MNGR_PRDC_SCN_ERR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ADV_EXT_MNGR_PRDC_SCN_ERR_CBK */

#if (USE_RT_DEBUG_BIG_ADV_CBK == 1)
  [DBG_IO_BIG_ADV_CBK] = RT_DEBUG_BIG_ADV_CBK,
#else
  [DBG_IO_BIG_ADV_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_BIG_ADV_CBK */

#if (USE_RT_DEBUG_BIG_ADV_ERR_CBK == 1)
  [DBG_IO_BIG_ADV_ERR_CBK] = RT_DEBUG_BIG_ADV_ERR_CBK,
#else
  [DBG_IO_BIG_ADV_ERR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_BIG_ADV_ERR_CBK */

#if (USE_RT_DEBUG_BIG_SYNC_CBK == 1)
  [DBG_IO_BIG_SYNC_CBK] = RT_DEBUG_BIG_SYNC_CBK,
#else
  [DBG_IO_BIG_SYNC_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_BIG_SYNC_CBK */

#if (USE_RT_DEBUG_BIG_SYNC_ERR_CBK == 1)
  [DBG_IO_BIG_SYNC_ERR_CBK] = RT_DEBUG_BIG_SYNC_ERR_CBK,
#else
  [DBG_IO_BIG_SYNC_ERR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_BIG_SYNC_ERR_CBK */

#if (USE_RT_DEBUG_ISO_CIS_PKT_TRNSM_RECEIVED_CBK == 1)
  [DBG_IO_ISO_CIS_PKT_TRNSM_RECEIVED_CBK] = RT_DEBUG_ISO_CIS_PKT_TRNSM_RECEIVED_CBK,
#else
  [DBG_IO_ISO_CIS_PKT_TRNSM_RECEIVED_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ISO_CIS_PKT_TRNSM_RECEIVED_CBK */

#if (USE_RT_DEBUG_ISO_CIG_ERR_CBK == 1)
  [DBG_IO_ISO_CIG_ERR_CBK] = RT_DEBUG_ISO_CIG_ERR_CBK,
#else
  [DBG_IO_ISO_CIG_ERR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ISO_CIG_ERR_CBK */

#if (USE_RT_DEBUG_CONN_PKT_TRNSM_RECEIVED_CBK == 1)
  [DBG_IO_CONN_PKT_TRNSM_RECEIVED_CBK] = RT_DEBUG_CONN_PKT_TRNSM_RECEIVED_CBK,
#else
  [DBG_IO_CONN_PKT_TRNSM_RECEIVED_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_CONN_PKT_TRNSM_RECEIVED_CBK */

#if (USE_RT_DEBUG_PRDC_CLBR_EXTRL_CBK == 1)
  [DBG_IO_PRDC_CLBR_EXTRL_CBK] = RT_DEBUG_PRDC_CLBR_EXTRL_CBK,
#else
  [DBG_IO_PRDC_CLBR_EXTRL_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_PRDC_CLBR_EXTRL_CBK */

#if (USE_RT_DEBUG_PTR_PRDC_ADV_SYNC_CBK == 1)
  [DBG_IO_PTR_PRDC_ADV_SYNC_CBK] = RT_DEBUG_PTR_PRDC_ADV_SYNC_CBK,
#else
  [DBG_IO_PTR_PRDC_ADV_SYNC_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_PTR_PRDC_ADV_SYNC_CBK */

#if (USE_RT_DEBUG_NCONN_SCN_CBK == 1)
  [DBG_IO_NCONN_SCN_CBK] = RT_DEBUG_NCONN_SCN_CBK,
#else
  [DBG_IO_NCONN_SCN_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_NCONN_SCN_CBK */

#if (USE_RT_DEBUG_NCONN_ADV_CBK == 1)
  [DBG_IO_NCONN_ADV_CBK] = RT_DEBUG_NCONN_ADV_CBK,
#else
  [DBG_IO_NCONN_ADV_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_NCONN_ADV_CBK */

#if (USE_RT_DEBUG_NCONN_INIT_CBK == 1)
  [DBG_IO_NCONN_INIT_CBK] = RT_DEBUG_NCONN_INIT_CBK,
#else
  [DBG_IO_NCONN_INIT_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_NCONN_INIT_CBK */

#if (USE_RT_DEBUG_ANT_RADIO_CMPLT_EVNT_CBK == 1)
  [DBG_IO_ANT_RADIO_CMPLT_EVNT_CBK] = RT_DEBUG_ANT_RADIO_CMPLT_EVNT_CBK,
#else
  [DBG_IO_ANT_RADIO_CMPLT_EVNT_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ANT_RADIO_CMPLT_EVNT_CBK */

#if (USE_RT_DEBUG_ANT_STACK_EVNT_CBK == 1)
  [DBG_IO_ANT_STACK_EVNT_CBK] = RT_DEBUG_ANT_STACK_EVNT_CBK,
#else
  [DBG_IO_ANT_STACK_EVNT_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ANT_STACK_EVNT_CBK */

#if (USE_RT_DEBUG_ADV_EXT_PROCESS_TMOUT_EVNT_CBK == 1)
  [DBG_IO_ADV_EXT_PROCESS_TMOUT_EVNT_CBK] = RT_DEBUG_ADV_EXT_PROCESS_TMOUT_EVNT_CBK,
#else
  [DBG_IO_ADV_EXT_PROCESS_TMOUT_EVNT_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ADV_EXT_PROCESS_TMOUT_EVNT_CBK */

#if (USE_RT_DEBUG_ADV_EXT_MNGR_SCN_DUR_EVNT == 1)
  [DBG_IO_ADV_EXT_MNGR_SCN_DUR_EVNT] = RT_DEBUG_ADV_EXT_MNGR_SCN_DUR_EVNT,
#else
  [DBG_IO_ADV_EXT_MNGR_SCN_DUR_EVNT] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ADV_EXT_MNGR_SCN_DUR_EVNT */

#if (USE_RT_DEBUG_ADV_EXT_MNGR_SCN_PERIODIC_EVNT == 1)
  [DBG_IO_ADV_EXT_MNGR_SCN_PERIODIC_EVNT] = RT_DEBUG_ADV_EXT_MNGR_SCN_PERIODIC_EVNT,
#else
  [DBG_IO_ADV_EXT_MNGR_SCN_PERIODIC_EVNT] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ADV_EXT_MNGR_SCN_PERIODIC_EVNT */

#if (USE_RT_DEBUG_ADV_EXT_MNGR_PRDC_SCN_TMOUT_EVNT == 1)
  [DBG_IO_ADV_EXT_MNGR_PRDC_SCN_TMOUT_EVNT] = RT_DEBUG_ADV_EXT_MNGR_PRDC_SCN_TMOUT_EVNT,
#else
  [DBG_IO_ADV_EXT_MNGR_PRDC_SCN_TMOUT_EVNT] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ADV_EXT_MNGR_PRDC_SCN_TMOUT_EVNT */

#if (USE_RT_DEBUG_ADV_EXT_MNGR_PRDC_SCN_CNCEL_EVNT == 1)
  [DBG_IO_ADV_EXT_MNGR_PRDC_SCN_CNCEL_EVNT] = RT_DEBUG_ADV_EXT_MNGR_PRDC_SCN_CNCEL_EVNT,
#else
  [DBG_IO_ADV_EXT_MNGR_PRDC_SCN_CNCEL_EVNT] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ADV_EXT_MNGR_PRDC_SCN_CNCEL_EVNT */

#if (USE_RT_DEBUG_BIS_MNGR_BIG_TERM_CBK == 1)
  [DBG_IO_BIS_MNGR_BIG_TERM_CBK] = RT_DEBUG_BIS_MNGR_BIG_TERM_CBK,
#else
  [DBG_IO_BIS_MNGR_BIG_TERM_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_BIS_MNGR_BIG_TERM_CBK */

#if (USE_RT_DEBUG_BIS_MNGR_SYNC_TMOUT_CBK == 1)
  [DBG_IO_BIS_MNGR_SYNC_TMOUT_CBK] = RT_DEBUG_BIS_MNGR_SYNC_TMOUT_CBK,
#else
  [DBG_IO_BIS_MNGR_SYNC_TMOUT_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_BIS_MNGR_SYNC_TMOUT_CBK */

#if (USE_RT_DEBUG_ISOAL_MNGR_SDU_GEN == 1)
  [DBG_IO_ISOAL_MNGR_SDU_GEN] = RT_DEBUG_ISOAL_MNGR_SDU_GEN,
#else
  [DBG_IO_ISOAL_MNGR_SDU_GEN] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ISOAL_MNGR_SDU_GEN */

#if (USE_RT_DEBUG_ISO_MNGR_CIS_PROCESS_EVNT_CBK == 1)
  [DBG_IO_ISO_MNGR_CIS_PROCESS_EVNT_CBK] = RT_DEBUG_ISO_MNGR_CIS_PROCESS_EVNT_CBK,
#else
  [DBG_IO_ISO_MNGR_CIS_PROCESS_EVNT_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ISO_MNGR_CIS_PROCESS_EVNT_CBK */

#if (USE_RT_DEBUG_CONN_MNGR_PROCESS_EVNT_CLBK == 1)
  [DBG_IO_CONN_MNGR_PROCESS_EVNT_CLBK] = RT_DEBUG_CONN_MNGR_PROCESS_EVNT_CLBK,
#else
  [DBG_IO_CONN_MNGR_PROCESS_EVNT_CLBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_CONN_MNGR_PROCESS_EVNT_CLBK */

#if (USE_RT_DEBUG_CONN_MNGR_UPDT_CONN_PARAM_CBK == 1)
  [DBG_IO_CONN_MNGR_UPDT_CONN_PARAM_CBK] = RT_DEBUG_CONN_MNGR_UPDT_CONN_PARAM_CBK,
#else
  [DBG_IO_CONN_MNGR_UPDT_CONN_PARAM_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_CONN_MNGR_UPDT_CONN_PARAM_CBK */

#if (USE_RT_DEBUG_EVNT_SCHDLR_HW_EVNT_CMPLT == 1)
  [DBG_IO_EVNT_SCHDLR_HW_EVNT_CMPLT] = RT_DEBUG_EVNT_SCHDLR_HW_EVNT_CMPLT,
#else
  [DBG_IO_EVNT_SCHDLR_HW_EVNT_CMPLT] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_EVNT_SCHDLR_HW_EVNT_CMPLT */

#if (USE_RT_DEBUG_HCI_EVENT_HNDLR == 1)
  [DBG_IO_HCI_EVENT_HNDLR] = RT_DEBUG_HCI_EVENT_HNDLR,
#else
  [DBG_IO_HCI_EVENT_HNDLR] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_HCI_EVENT_HNDLR */

#if (USE_RT_DEBUG_MLME_TMRS_CBK == 1)
  [DBG_IO_MLME_TMRS_CBK] = RT_DEBUG_MLME_TMRS_CBK,
#else
  [DBG_IO_MLME_TMRS_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_MLME_TMRS_CBK */

#if (USE_RT_DEBUG_DIRECT_TX_EVNT_CBK == 1)
  [DBG_IO_DIRECT_TX_EVNT_CBK] = RT_DEBUG_DIRECT_TX_EVNT_CBK,
#else
  [DBG_IO_DIRECT_TX_EVNT_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_DIRECT_TX_EVNT_CBK */

#if (USE_RT_DEBUG_INDIRECT_PKT_TOUR_CBK == 1)
  [DBG_IO_INDIRECT_PKT_TOUR_CBK] = RT_DEBUG_INDIRECT_PKT_TOUR_CBK,
#else
  [DBG_IO_INDIRECT_PKT_TOUR_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_INDIRECT_PKT_TOUR_CBK */

#if (USE_RT_DEBUG_RADIO_CSMA_TMR == 1)
  [DBG_IO_RADIO_CSMA_TMR] = RT_DEBUG_RADIO_CSMA_TMR,
#else
  [DBG_IO_RADIO_CSMA_TMR] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RADIO_CSMA_TMR */

#if (USE_RT_DEBUG_RAL_SM_DONE_EVNT_CBK == 1)
  [DBG_IO_RAL_SM_DONE_EVNT_CBK] = RT_DEBUG_RAL_SM_DONE_EVNT_CBK,
#else
  [DBG_IO_RAL_SM_DONE_EVNT_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_RAL_SM_DONE_EVNT_CBK */

#if (USE_RT_DEBUG_ED_TMR_HNDL == 1)
  [DBG_IO_ED_TMR_HNDL] = RT_DEBUG_ED_TMR_HNDL,
#else
  [DBG_IO_ED_TMR_HNDL] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_ED_TMR_HNDL */

#if (USE_RT_DEBUG_OS_TMR_EVNT_CBK == 1)
  [DBG_IO_OS_TMR_EVNT_CBK] = RT_DEBUG_OS_TMR_EVNT_CBK,
#else
  [DBG_IO_OS_TMR_EVNT_CBK] = RT_DEBUG_SIGNAL_UNUSED,
#endif /* USE_RT_DEBUG_OS_TMR_EVNT_CBK */
};

#endif /* RT_DEBUG_GPIO_MODULE */

#endif /* LOCAL_DEBUG_TABLES_H*/
